$(document).ready(function($) {

    'use strict';

    $('#preloader').css('display', 'none');
    $.material.init()
    $.Outlay = {};

    /* --------------------
     * - Outlay Options -
     * --------------------
     * Modify these options to suit your implementation
     */
    $.Outlay.options = {

        sidebarToggleSelector: "[data-toggle='offcanvas']",
        sidebarPushMenu: true,
        enableControlSidebar: true,
        controlSidebarOptions: {
            toggleBtnSelector: "[data-toggle='control-sidebar']",
            selector: ".control-sidebar",
            slide: true
        },

        screenSizes: {
            xs: 480,
            sm: 768,
            md: 992,
            lg: 1200
        }
    };


    $("body").removeClass("hold-transition");

    if (typeof OutlayOptions !== "undefined") {
        $.extend(true,
            $.Outlay.options,
            OutlayOptions);
    }

    //Easy access to options
    var o = $.Outlay.options;

    //Set up the object
    _init();

    //Activate the layout maker
    $.Outlay.layout.activate();

    //Enable sidebar tree view controls
    $.Outlay.tree('.sidebar');


    //Add slimscroll to navbar dropdown
    if (o.navbarMenuSlimscroll && typeof $.fn.slimscroll != 'undefined') {
        $(".navbar .menu").slimscroll({
            height: o.navbarMenuHeight,
            alwaysVisible: false,
            size: o.navbarMenuSlimscrollWidth
        }).css("width", "100%");
    }

    //Activate sidebar push menu
    if (o.sidebarPushMenu) {
        $.Outlay.pushMenu.activate(o.sidebarToggleSelector);
    }




    /* ----------------------------------
     * - Initialize the Outlay Object -
     * ----------------------------------
     */
    function _init() {
        'use strict';
        /* Layout*/
        $.Outlay.layout = {
            activate: function() {
                var _this = this;
                _this.fix();
                _this.fixSidebar();
                $(window, ".wrapper").resize(function() {
                    _this.fix();
                    _this.fixSidebar();
                });
            },
            fix: function() {
                //Get window height and the wrapper height
                var neg = $('.main-header').outerHeight() + $('.main-footer').outerHeight();
                var window_height = $(window).height();
                var sidebar_height = $(".sidebar").height();
                //Set the min-height of the content and sidebar based on the
                //the height of the document.
                if ($("body").hasClass("fixed")) {
                    $(".content-wrapper, .right-side").css('min-height', window_height - $('.main-footer').outerHeight());
                } else {
                    var postSetWidth;
                    if (window_height >= sidebar_height) {
                        $(".content-wrapper, .right-side").css('min-height', window_height - neg);
                        postSetWidth = window_height - neg;
                    } else {
                        $(".content-wrapper, .right-side").css('min-height', sidebar_height);
                        postSetWidth = sidebar_height;
                    }

                    //Fix for the control sidebar height
                    var controlSidebar = $($.Outlay.options.controlSidebarOptions.selector);
                    if (typeof controlSidebar !== "undefined") {
                        if (controlSidebar.height() > postSetWidth)
                            $(".content-wrapper, .right-side").css('min-height', controlSidebar.height());
                    }

                }
            },
            fixSidebar: function() {
                //Make sure the body tag has the .fixed class
                if (!$("body").hasClass("fixed")) {
                    if (typeof $.fn.slimScroll != 'undefined') {
                        $(".sidebar").slimScroll({ destroy: true }).height("auto");
                    }
                    return;
                } else if (typeof $.fn.slimScroll == 'undefined' && window.console) {
                    window.console.error("Error: the fixed layout requires the slimscroll plugin!");
                }
                //Enable slimscroll for fixed layout
                if ($.Outlay.options.sidebarSlimScroll) {
                    if (typeof $.fn.slimScroll != 'undefined') {
                        //Destroy if it exists
                        $(".sidebar").slimScroll({ destroy: true }).height("auto");
                        //Add slimscroll
                        $(".sidebar").slimscroll({
                            height: ($(window).height() - $(".main-header").height()) + "px",
                            color: "rgba(0,0,0,0.2)",
                            size: "3px"
                        });
                    }
                }
            }
        };

        /* Push Menu
         * ==========
         * Adds the push menu functionality to the sidebar.
         */
        $.Outlay.pushMenu = {
            activate: function(toggleBtn) {
                //Get the screen sizes
                var screenSizes = $.Outlay.options.screenSizes;

                //Enable sidebar toggle
                $(toggleBtn).on('click', function(e) {
                    e.preventDefault();

                    //Enable sidebar push menu
                    if ($(window).width() > (screenSizes.sm - 1)) {
                        if ($("body").hasClass('sidebar-collapse')) {
                            $("body").removeClass('sidebar-collapse').trigger('expanded.pushMenu');
                        } else {
                            $("body").addClass('sidebar-collapse').trigger('collapsed.pushMenu');
                        }
                    }
                    //Handle sidebar push menu for small screens
                    else {
                        if ($("body").hasClass('sidebar-open')) {
                            $("body").removeClass('sidebar-open').removeClass('sidebar-collapse').trigger('collapsed.pushMenu');
                        } else {
                            $("body").addClass('sidebar-open').trigger('expanded.pushMenu');
                        }
                    }
                });


                $(".content-wrapper").on('click', function() {
                    //Enable hide menu when clicking on the content-wrapper on small screens
                    if ($(window).width() <= (screenSizes.sm - 1) && $("body").hasClass("sidebar-open")) {
                        $("body").removeClass('sidebar-open');
                    }

                });

                //Enable expand on hover for sidebar mini
                if ($.Outlay.options.sidebarExpandOnHover || ($('body').hasClass('fixed') && $('body').hasClass('sidebar-mini'))) {
                    this.expandOnHover();
                }
            },
            expandOnHover: function() {
                var _this = this;
                var screenWidth = $.Outlay.options.screenSizes.sm - 1;
                //Expand sidebar on hover
                $('.main-sidebar').on('hover',function() {
                    if ($('body').hasClass('sidebar-mini') && $("body").hasClass('sidebar-collapse') && $(window).width() > screenWidth) {
                        _this.expand();
                    }
                }, function() {
                    if ($('body').hasClass('sidebar-mini') && $('body').hasClass('sidebar-expanded-on-hover') && $(window).width() > screenWidth) {
                        _this.collapse();
                    }
                });
            },
            expand: function() {
                $("body").removeClass('sidebar-collapse').addClass('sidebar-expanded-on-hover');
            },
            collapse: function() {
                if ($('body').hasClass('sidebar-expanded-on-hover')) {
                    $('body').removeClass('sidebar-expanded-on-hover').addClass('sidebar-collapse');
                }
            }
        };

        /* Tree menu */

        $.Outlay.tree = function(menu) {
            var _this = this;
            var animationSpeed = $.Outlay.options.animationSpeed;
            $(document).on('click', menu + ' li a', function(e) {
                //Get the clicked link and the next element
                var $this = $(this);
                var checkElement = $this.next();

                //Check if the next element is a menu and is visible
                if ((checkElement.is('.treeview-menu')) && (checkElement.is(':visible'))) {
                    //Close the menu
                    checkElement.slideUp(animationSpeed, function() {
                        checkElement.removeClass('menu-open');
                        //Fix the layout in case the sidebar stretches over the height of the window
                        //_this.layout.fix();
                    });
                    checkElement.parent("li").removeClass("active");
                }
                //If the menu is not visible
                else if ((checkElement.is('.treeview-menu')) && (!checkElement.is(':visible'))) {
                    //Get the parent menu
                    var parent = $this.parents('ul').first();
                    //Close all open menus within the parent
                    var ul = parent.find('ul:visible').slideUp(animationSpeed);
                    //Remove the menu-open class from the parent
                    ul.removeClass('menu-open');
                    //Get the parent li
                    var parent_li = $this.parent("li");

                    //Open the target menu and add the menu-open class
                    checkElement.slideDown(animationSpeed, function() {
                        //Add the class active to the parent li
                        checkElement.addClass('menu-open');
                        parent.find('li.active').removeClass('active');
                        parent_li.addClass('active');
                        $('.treeview.active .fa.fa-angle-right.pull-right').addClass('rotate-icon');
                        //Fix the layout in case the sidebar stretches over the height of the window
                        _this.layout.fix();
                    });
                }
                //if this isn't a link, prevent the page from being redirected
                if (checkElement.is('.treeview-menu')) {
                    e.preventDefault();
                }
            });
        };

        $('#open-history-state-button').on('click', function(e) {
            e.preventDefault();

            var data = {};

            data.action = 'history-payment-state';
            $.getJSON(
                '',
                data,
                function (json) {
                    if(json.success){
                        if (json.history.length > 0){
                            $('#history-payment-state-content').empty();
                            var table = '<table style="width: 100%">';
                            table += "<tr><th>Stato</th><th>Data</th><th>Tramite</th></tr>";
                            json.history.forEach(function(element){
                                element.stateName = '';
                                switch (element.id_agreementState) {
                                    case 0 :{
                                        element.stateName = 'Da lavorare';
                                    } break;
                                    case 1 :{
                                        element.stateName = 'Dati sbagliati/Incompleti';
                                    }break;
                                    case 2 :{
                                        element.stateName = 'Inviato';
                                    }break;
                                    case 3 :{
                                        element.stateName = 'KO';
                                    }break;
                                    case 4 :{
                                        element.stateName = 'Ripresentato (x1)';
                                    }break;
                                    case 5 :{
                                        element.stateName = 'Ripresentato (x2)';
                                    }break;
                                    case 6 :{
                                        element.stateName = 'Incassato';
                                    }break;
                                    case 11 :{
                                        element.stateName = 'Incassato - Bloccato';
                                    }break;
                                    case 7 :{
                                        element.stateName = 'Stornato';
                                    }break;
                                    case 8 :{
                                        element.stateName = 'Gratis';
                                    }break;
                                    case 9 :{
                                        element.stateName = 'Non Incassato';
                                    }break;
                                    case 10 :{
                                        element.stateName = 'Non Incassato - Annullato';
                                    }break;
                                    case 12 :{
                                        element.stateName = 'Rimborsato';
                                    }break;
                                }
                                element.cashedName = '';
                                switch (element.cashedType) {
                                    case 0 :{
                                        element.cashedType = 'Bonifico';
                                    } break;
                                    case 1 :{
                                        element.cashedType = 'Compensazione';
                                    }break;
                                    case 2 :{
                                        element.cashedType = 'Provvigioni';
                                    }break;
                                    case 3 :{
                                        element.cashedType = 'Bonus';
                                    }break;
                                    case 4 :{
                                        element.cashedType = 'Assegni';
                                    }break;
                                    case 5 :{
                                        element.cashedType = 'Contanti';
                                    }break;
                                }
                                table += '<tr style="padding-top: 5px;">\
                                            <td>Stato</td>\
                                            <td>' + element.stateName + '</td>\
                                            <td>' + element.stateDate + '</td>\
                                        </tr>\
                                        <tr style="border-bottom: 1px solid; padding-bottom: 5px;">\
                                            <td>Incassato</td>\
                                            <td>' + element.cashedType + '</td>\
                                            <td>' + element.cashedDate + '</td>\
                                        </tr>\
                                ';
                            });

                            table += '</table>';
                            $('#history-payment-state-content').html(table);
                        }
                        console.log(json);
                    }
                }
            );
            $('#history-payment-state').modal('show');
        });

        $('#open-switch-state-button').on('click', function(e) {
            e.preventDefault();
            $('#switch-payment-state').modal('show');
        });
		// switch and switch-billings
        $('.open-switch-modal').on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            openSwitchModal(this);
        });
        $('.show-switch-history').on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            showSwitchHistory(this);
        });
        $('#history-switch-modal').on('click', 'button', function(e) {
            e.preventDefault();
            e.stopPropagation();
        });
        $('.open-new-billing-button').on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            newBilling(this);
        });

        $('[name=new-supplier-turned]').change(function() {
            let modal = $('#switch-supplier-modal');
            modal.find('[name=new-supplier-turned-name]').val('');
            modal.find('[name=new-supplier-turned-surname]').val('');
            modal.find('[name=new-supplier-turned-fiscalcode]').val('');
            modal.find('[name=new-supplier-turned-name]').prop( "disabled", !$(this).is(':checked') );
            modal.find('[name=new-supplier-turned-surname]').prop( "disabled", !$(this).is(':checked') );
            modal.find('[name=new-supplier-turned-fiscalcode]').prop( "disabled", !$(this).is(':checked') );
        });
        $('[name=new-supplier-turned]').change();

    }

    $(".comment-item").each(function (key, item){
        initNotes($(item));
    });


    /* Dropdown Effect with animate js */

    var dropdownSelectors = $('.dropdown, .dropup');

    // Custom function to read dropdown data
    // =========================
    function dropdownEffectData(target) {
        // @todo - page level global?
        var effectInDefault = null,
            effectOutDefault = null;
        var dropdown = $(target),
            dropdownMenu = $('.dropdown-menu', target);
        var parentUl = dropdown.parents('ul.nav');

        // If parent is ul.nav allow global effect settings
        if (parentUl.length > 0) {
            effectInDefault = parentUl.data('dropdown-in') || null;
            effectOutDefault = parentUl.data('dropdown-out') || null;
        }

        return {
            target: target,
            dropdown: dropdown,
            dropdownMenu: dropdownMenu,
            effectIn: dropdownMenu.data('dropdown-in') || effectInDefault,
            effectOut: dropdownMenu.data('dropdown-out') || effectOutDefault,
        };
    }

    // Custom function to start effect (in or out)
    // =========================
    function dropdownEffectStart(data, effectToStart) {
        if (effectToStart) {
            data.dropdown.addClass('dropdown-animating');
            data.dropdownMenu.addClass('animated');
            data.dropdownMenu.addClass(effectToStart);
        }
    }

    // Custom function to read when animation is over
    // =========================
    function dropdownEffectEnd(data, callbackFunc) {
        var animationEnd = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';
        data.dropdown.one(animationEnd, function() {
            data.dropdown.removeClass('dropdown-animating');
            data.dropdownMenu.removeClass('animated');
            data.dropdownMenu.removeClass(data.effectIn);
            data.dropdownMenu.removeClass(data.effectOut);

            // Custom callback option, used to remove open class in out effect
            if (typeof callbackFunc == 'function') {
                callbackFunc();
            }
        });
    }

    // Bootstrap API hooks
    // =========================
    dropdownSelectors.on({
        "show.bs.dropdown": function() {
            // On show, start in effect
            var dropdown = dropdownEffectData(this);
            dropdownEffectStart(dropdown, dropdown.effectIn);
        },
        "shown.bs.dropdown": function() {
            // On shown, remove in effect once complete
            var dropdown = dropdownEffectData(this);
            if (dropdown.effectIn && dropdown.effectOut) {
                dropdownEffectEnd(dropdown, function() {});
            }
        }

    });

    /* fullscreen */

    function toggleFullScreen() {
        if ((document.fullScreenElement && document.fullScreenElement !== null) ||
            (!document.mozFullScreen && !document.webkitIsFullScreen)) {
            if (document.documentElement.requestFullScreen) {
                document.documentElement.requestFullScreen();
            } else if (document.documentElement.mozRequestFullScreen) {
                document.documentElement.mozRequestFullScreen();
            } else if (document.documentElement.webkitRequestFullScreen) {
                document.documentElement.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT);
            }
        } else {
            if (document.cancelFullScreen) {
                document.cancelFullScreen();
            } else if (document.mozCancelFullScreen) {
                document.mozCancelFullScreen();
            } else if (document.webkitCancelFullScreen) {
                document.webkitCancelFullScreen();
            }
        }
    }

    $('.toggle-fullscreen').on('click',function() {
        toggleFullScreen();
    });


    /*Popover*/
    $('[data-toggle="popover"]').popover();

    /*Slimscroll*/
    $('.notification-menu').slimscroll({ height: '220px', color: '#566fc9', size: '5px' });

    $(".panel.min .action-click").click(function(){
        $(this).parents('.panel.min').eq(0).toggleClass('exploded');
    });

    $('.date').datetimepicker({
        format: 'DD/MM/YYYY'
    });


    $('.carrier-auto-update').change(function(){
        var data = {};
        data.id = $(this).attr('name');
        data.value = $(this).val();
        data.json = true;
        $.getJSON('', data, function (data) {
            if(data.success){
                OutLay.displaySuccess('Carriera aggiornata', 'La carriera è stata aggiornata da "' + data.lastCarrier + '" a "' + data.newCarrier + '".')
            }
            console.log(data);
        });
    });
});

$('.activatable').click(function () {
    event.preventDefault();
    var el = $(this);
    if(el.data('activatable-name') !== undefined){
        var data = {};
        data.agreementType = {};
        data.agreementType[el.data('activatable-name')] = el.data('activatable-value');
        $.getJSON(
            el.attr('href'),
            data,
            function (json) {
                console.log(json);
                console.log(json.success);
                if(json.success){
                    var flag = !el.data('activatable-value');
                    console.log(flag);
                    var success = el.parent().find('[data-activatable-value=0]');
                    var error = el.parent().find('[data-activatable-value=1]');
                    console.log(success);
                    console.log(error);
                    success.removeClass('hidden');
                    error.removeClass('hidden');
                    if(flag){
                        success.addClass('hidden');
                    } else {
                        error.addClass('hidden');
                    }
                }
            }
        );
    }
});

function editAgreementType(id){
    $.getJSON(
        '/prices/' + id + '.json',
        function (json){
            if(json.success){
                for(var i in json.data){
                    var element = json.data[i];
                    if($("#agreementType-edit [name='agreementType["+i+"]']").length){
                        var field = $("#agreementType-edit [name='agreementType["+i+"]']");
                        var inputCheckable = [
                            'checkbox',
                            'radio'
                        ];
                        var searching = true;
                        if(field[0].tagName.toLowerCase() == 'input' && inputCheckable.indexOf(field.attr('type')) != -1){
                            field.each(function (k, el) {
                                el.prop('selected', false);
                                if(el.val() == element && searching){
                                    searching = false;
                                    el.prop('selected', true);
                                }
                            });
                        } else if (field[0].tagName.toLowerCase() == 'input' || field[0].tagName.toLowerCase() == 'select'){
                            if(field[0].tagName.toLowerCase() == 'select'){
                                console.log(i);
                                console.log(element);
                            }
                            field.val(element);
                        } else if (field[0].tagName.toLowerCase() == 'select'){
                            field.find('option').each(function (k, el) {
                                el.prop('selected', false);
                                if(el.val() == element && searching){
                                    searching = false;
                                    el.prop('selected', true);
                                }
                            });
                            if(searching){
                                field.find('option').each(function (k, el) {
                                    el.prop('selected', false);
                                    if(el.text().toLowerCase() == element.toLowerCase() && searching){
                                        searching = false;
                                        el.prop('selected', true);
                                    }
                                });
                            }
                        }
                    }
                };
                $('#agreementType-edit [name=agreementType-id]').val(id);
                $('#agreementType-edit input').each(function(k, e){$(e).change();});
                $('#agreementType-edit').modal('show');
            }
        }
    );
}

function saveAgreementType(){
    var id = $('#agreementType-edit [name=agreementType-id]').val();
    var data = $('#agreementType-edit form').serialize();
    $.getJSON(
        '/prices/' + id + '.json',
        data,
        function (json){
            location.reload();
        }
    );
}

function editDistributor(id, description){
    var modal = $("#distributor-edit");
    modal.find('input[name=distributor-id]').val(id);
    modal.find('input[name="agreementType[name]"]').val(description);
    modal.find('input[name="agreementType[name]"]').change();
    modal.modal('show');
}

function saveDistributor(){
    var modal = $("#distributor-edit");
    modal.modal('hide');
    var data = {};
    data.id = modal.find('input[name=distributor-id]').val();
    data.description = modal.find('input[name="agreementType[name]"]').val();
    $.getJSON('', data, function(json){
        if(json.success == true){
            location.reload();
        } else {
            var error = new OutLay.error("", {
                error: 'Salvataggio non riuscito',
                subject: 'Non è stato possibile salvare le modifiche'
            });
            error.display();
        }
    });
}

function newDistributor(){
    var modal = $("#distributor-edit");
    modal.find('input[name=distributor-id]').val('');
    modal.find('input[name="agreementType[name]"]').val('');
    modal.find('input[name="agreementType[name]"]').change();
    modal.modal('show');
}

function openCommission() {
    $('#add-commission').modal('show');
}

function newCommission() {
    var data = {};
    data.code = $('#add-commission input[name="commission[code]"]').val();
    data.carrier = $('#add-commission input[name="commission[carrier]"]').val();
    data.dateStart = $('#add-commission input[name="commission[dateStart]"]').val();
    data.dateEnd = $('#add-commission input[name="commission[dateEnd]"]').val();
    data.action = 'new_commission';
    post('', data);
}
function post(path, params, method) {
    method = method || "post"; // Set method to post by default if not specified.

    // The rest of this code assumes you are not using a library.
    // It can be made less wordy if you use one.
    var form = document.createElement("form");
    form.setAttribute("method", method);
    form.setAttribute("action", path);

    for(var key in params) {
        if(params.hasOwnProperty(key)) {
            var hiddenField = document.createElement("input");
            hiddenField.setAttribute("type", "hidden");
            hiddenField.setAttribute("name", key);
            hiddenField.setAttribute("value", params[key]);

            form.appendChild(hiddenField);
        }
    }

    document.body.appendChild(form);
    form.submit();
}

function initNotes(noteModal, all){
    if(all == undefined){
        all = false;
    }
    noteModal = $(noteModal);
    noteModal.find('.loader').removeClass('disabled');
    var noteRef = $("[href='#" + noteModal.attr('id') + "']");
    var idThread = noteModal.data('notethread');
    noteRef.click(function(){
        event.preventDefault();
        noteModal.modal('show');

    });

    var dataVariables = {getnotes:true,noteThread:idThread};
    if(all){
        dataVariables.number = -1;
        noteModal.find( "[href='#load-all-comments']").addClass('disabled');
    }

    $.post('', dataVariables, function(data) {
        if(data.length > 0){
            var list = noteModal.find('.comment-list');
            list.html('');
            data.forEach(function (item){
                var element  = $('<li></li>');
                if(item.flag_done == 1){
                    element.addClass('note-done');
                }
                element.append($('<span></span>').html(item.note).addClass('note-text').data('noteid', item.id));
                element.append($('<span></span>').text('X').addClass('note-delete').data('noteid', item.id));
                list.prepend(element);
                if(item.flag_done){
                    element.find('.note-text').addClass('note-checked');
                }
            });

            setTimeout(function(){
                var container = noteModal.find(".comment-container");
                var scrollContainer = list.outerHeight() - container.outerHeight();
                container.animate({
                    scrollTop: scrollContainer
                }, 1000);
            }, 100);
        }
        noteModal.on('click', '.note-text', function(){
            var note = $(this);
            var idNote = note.data('noteid');
            var checked = !note.hasClass('note-checked');
            $.post('', {checkNote:true,id:idNote,check:checked}, function(data) {
                if(data.success == true){
                    if(checked){
                        note.addClass('note-checked');
                    } else {
                        note.removeClass('note-checked');
                    }
                }
            }, 'json');
        });
        noteModal.on('click', '.note-delete', function(){
            var note = $(this);
            var idNote = note.data('noteid');
            $.post('', {deleteNote:true,id:idNote}, function(data) {
                if(data.success == true){
                    note.parent().remove();
                }
            }, 'json');
        });
        noteModal.find('.loader').addClass('disabled');

        noteModal.on('click', "[href='#load-all-comments']", function(){
            initNotes(noteModal, true);
        });
        noteModal.on('click', ".add-comment", function(){
            note = noteModal.find('[name="new-comment"]').val();
            noteModal.find('[name="new-comment"]').val('');
            var idThread = noteModal.data('notethread');
            $.post('', {addNote:true,idThread:idThread,note:note}, function(data) {
                if(data.success == true){
                    var list = noteModal.find('.comment-list');
                    var element  = $('<li></li>');
                    element.append($('<span></span>').text(note).addClass('note-text').data('noteid', data.id));
                    element.append($('<span></span>').text('X').addClass('note-delete').data('noteid', data.id));
                    list.append(element);
                }
            }, 'json');
        });
    }, 'json');

}


function switchPaymentState(){
    var data = {};

    data.action = 'switch-payment-state';
    data.state = $('[name=switchContractState]').val();
    data.stateName = $('[name=switchContractState]').find('option:selected').text().trim();
    data.stateDate = $('[name=switchContractStateDate]').val();
    data.cashed = $('[name=switchCashedType]').val();
    data.cashedName = $('[name=switchCashedType]').find('option:selected').text().trim();
    data.cashedDate = $('[name=switchCashedTypeDate]').val();
    $.getJSON(
        '',
        data,
        function (json) {
            if(json.success){
                $('[name=switchContractStateLabel]').val(data.stateName);
                $('[name=switchContractStateDateLabel]').val(data.stateDate);
            }
        }
    );
    $('#switch-payment-state').modal('hide');
}
function closeSwitchPaymentState(){
    $('#switch-payment-state').modal('hide');
}

function updateAgreementsEmail(){
    $('#reload-agreement-email').modal('show');
    $('#reload-agreement-email .updating-agreement').each(function(k, el){
        let parent = el;
        let value = $(el).find('input').val();
        $.get( "/?update_single_mail_system&agreement_id=" + value, function( data ) {
            $(parent).addClass('done');
        });
    })
}


function openSwitchModal(element){
    let id_aU = $(element).parents('.form-horizontal').find('.agreement-utility-id-data').val();
    let id_aUS = $(element).parents('.form-horizontal').find('.a-u-last-switch-id-data').val();
    let modal = $('#switch-modal');
    let a_utility = modal.find('.agreement-utility-id-data');
    let a_utilitySupplier = modal.find('.a-u-last-switch-id-data');
    a_utility.val(id_aU);
    a_utilitySupplier.val(id_aUS);
    modal.modal('show');
}

function setSwitchSendData(){
    let modal = $('#switch-modal');
    modal.modal('hide');
    let a_currentSwitchId = modal.find('.a-u-last-switch-id-data').val();
    if (!a_currentSwitchId || a_currentSwitchId == ''){
        let error = "Nessun switch attivo da poter segnare come inviato.";
        error = new OutLay.error("xhr.response", {
            error: error,
            subject: error
        });
        error.display();
        return;
    }
    swal({
        title: "Attenzione",
        text: "Verrà contrasegnato come switch inviato!",
        type: "warning",
        showConfirmButton: true,
        showCancelButton: true,
        cancelButtonColor: "#d9534f",
        cancelButtonText: "Annulla",
        confirmButtonColor: "#5cb85c",
        confirmButtonText: "Salva",
        closeOnConfirm: false
    }, function() {
        swal({
            html: true,
            title: "Salvataggio",
            text: 'Stiamo verificando l\'integrità dei dati.<br>Ci vorranno pochi secondi.<br><br>' +
                '<div class="progress">\n' +
                '\t<div style="width: 100%;" class="progress-bar progress-bar-primary progress-bar-striped active"></div>\n' +
                '</div>',
            showConfirmButton: false,
            showCancelButton: false,
            closeOnConfirm: false
        });
        OutLay.currentSA.kill = setTimeout(function () {
            swal.close();
            var error = "Risposta del server innafidabile. Ritentare o contattare il supporto tecnico.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        }, 2*60*1000);
        ajaxSetSwitchSendDate(a_currentSwitchId);
    });
}

function ajaxSetSwitchSendDate(id){
    var formData = new FormData();
    formData.append('action', 'set-supplier-send-date');
    formData.append('id-supplier-history', id);

    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                if(json.status === 'OK' || json.status == 200){
                    console.log(json);
                    //heading, text, icon, duration
                    OutLay.displaySuccess("Modifica riuscita!", "Le tue modifiche sono state salvate con successo", true , 2000);
                    $('.a-u-last-switch-id-data').each(function(k, v){
                        if(v.value == id){
                            $(v).parent().find('.supplier-date-send').val(json['new-date']);
                        }
                    })
                } else {
                    for(var i in json.errors){
                        var error = json.errors[i];
                        error = new OutLay.error("customer.data", {
                            error: error.error,
                            subject: error.message
                        });
                        error.display();
                    }
                }
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Modifica Fallita.<br>Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}


function setSwitchEndData(){
    let modal = $('#switch-modal');
    modal.modal('hide');
    let a_currentSwitchId = modal.find('.a-u-last-switch-id-data').val();
    if (!a_currentSwitchId || a_currentSwitchId == ''){
        let error = "Nessun switch attivo da poter segnare come terminato.";
        error = new OutLay.error("xhr.response", {
            error: error,
            subject: error
        });
        error.display();
        return;
    }
    swal({
        title: "Attenzione",
        text: "Verrà contrasegnato come switch terminato!",
        type: "warning",
        showConfirmButton: true,
        showCancelButton: true,
        cancelButtonColor: "#d9534f",
        cancelButtonText: "Annulla",
        confirmButtonColor: "#5cb85c",
        confirmButtonText: "Salva",
        closeOnConfirm: false
    }, function() {
        swal({
            html: true,
            title: "Salvataggio",
            text: 'Stiamo verificando l\'integrità dei dati.<br>Ci vorranno pochi secondi.<br><br>' +
                '<div class="progress">\n' +
                '\t<div style="width: 100%;" class="progress-bar progress-bar-primary progress-bar-striped active"></div>\n' +
                '</div>',
            showConfirmButton: false,
            showCancelButton: false,
            closeOnConfirm: false
        });
        OutLay.currentSA.kill = setTimeout(function () {
            swal.close();
            var error = "Risposta del server innafidabile. Ritentare o contattare il supporto tecnico.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        }, 2*60*1000);
        ajaxSetSwitchEndDate(a_currentSwitchId);
    });
}


function ajaxSetSwitchEndDate(id){
    var formData = new FormData();
    formData.append('action', 'set-supplier-end-date');
    formData.append('id-supplier-history', id);

    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                if(json.status === 'OK' || json.status == 200){
                    console.log(json);
                    //heading, text, icon, duration
                    OutLay.displaySuccess("Modifica riuscita!", "Le tue modifiche sono state salvate con successo", true , 2000);
                } else {
                    for(var i in json.errors){
                        var error = json.errors[i];
                        error = new OutLay.error("customer.data", {
                            error: error.error,
                            subject: error.message
                        });
                        error.display();
                    }
                }
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Modifica Fallita.<br>Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function setNewSwitch(){
    let modalMain = $('#switch-modal');
    let modal = $('#switch-supplier-modal');
    let a_utilityM = modalMain.find('.agreement-utility-id-data');
    let a_utility = modal.find('.agreement-utility-id-data');
    a_utility.val(a_utilityM.val());
    $('.modal').modal('hide');
    let supplierSelect = modal.find('select');
    supplierSelect.select2('destroy');
    supplierSelect.children().each(function(k, v){
        $(v).remove();
    });
    supplierSelect.append($('<option>Ricevendo la lista di fornitori</option>'));
    $('[name=new-supplier-turned]').prop('checked', false);
    $('[name=new-supplier-turned]').change();
    getSuppliers();
    modal.modal('show');
}

function getSuppliers(){
    var formData = new FormData();
    formData.append('action', 'get-suppliers');
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                let modal = $('#switch-supplier-modal');
                let supplierSelect = modal.find('select');
                supplierSelect.children().each(function(k, v){
                    $(v).remove();
                });
                supplierSelect.append($('<option value="0">Fornitore</option>'));
                $(json.suppliers).each(function(k, v){
                    supplierSelect.append($('<option value="'+v.id+'">'+v.name+'</option>'));
                })
                supplierSelect.select2();
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function saveNewSwitch() {
    let modal = $('#switch-supplier-modal');
    if(modal.find('[name=new-supplier-id]').val() == 0){
        var error = "Devi prima selezionare un fornitore.";
        error = new OutLay.error("", {
            error: error,
            subject: error
        });
        error.display();
        return ;
    }
    modal.modal('hide');
    let a_currentAUtilityId = modal.find('.agreement-utility-id-data').val();
    swal({
        title: "Attenzione",
        text: "Verrà segnato un nuovo switch!",
        type: "warning",
        showConfirmButton: true,
        showCancelButton: true,
        cancelButtonColor: "#d9534f",
        cancelButtonText: "Annulla",
        confirmButtonColor: "#5cb85c",
        confirmButtonText: "Salva",
        closeOnConfirm: false
    }, function() {
        swal({
            html: true,
            title: "Salvataggio",
            text: 'Stiamo verificando l\'integrità dei dati.<br>Ci vorranno pochi secondi.<br><br>' +
                '<div class="progress">\n' +
                '\t<div style="width: 100%;" class="progress-bar progress-bar-primary progress-bar-striped active"></div>\n' +
                '</div>',
            showConfirmButton: false,
            showCancelButton: false,
            closeOnConfirm: false
        });
        OutLay.currentSA.kill = setTimeout(function () {
            swal.close();
            var error = "Risposta del server innafidabile. Ritentare o contattare il supporto tecnico.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        }, 2*60*1000);
        ajaxSaveNewSwitch(a_currentAUtilityId);
    });
}

function ajaxSaveNewSwitch(id) {
    var formData = new FormData();
    formData.append('action', 'set-new-supplier');
    formData.append('id-agreement-utility', id);

    let modal = $('#switch-supplier-modal');
    formData.append('id-supplier', modal.find('[name=new-supplier-id]').val());
    formData.append('turned', modal.find('[name=new-supplier-turned]').prop('checked'));
    formData.append('turned-name', modal.find('[name=new-supplier-turned-name]').val());
    formData.append('turned-surname', modal.find('[name=new-supplier-turned-surname]').val());
    formData.append('turned-fiscalcode', modal.find('[name=new-supplier-turned-fiscalcode]').val());
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                if(json.status === 'OK' || json.status == 200){
                    console.log(json);
                    //heading, text, icon, duration
                    location.reload();
                } else {
                    for(var i in json.errors){
                        var error = json.errors[i];
                        error = new OutLay.error("customer.data", {
                            error: error.error,
                            subject: error.message
                        });
                        error.display();
                    }
                }
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function showSwitchHistory(element){
    let id_aU = $(element).parents('.form-horizontal').find('.agreement-utility-id-data').val();
    let modal = $('#history-switch-modal');
    $('.modal').modal('hide');
    let parent = modal.find('.modal-body form');
    parent.children().remove();
    parent.append($('<span>Cercando lo storico...</span>'))
    getSupplierHistory(id_aU);
    modal.modal('show');
}
function getSupplierHistory(id){
    var formData = new FormData();
    formData.append('action', 'get-supplier-history');
    formData.append('id-agreement-utility', id);
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                let modal = $('#history-switch-modal');
                let parent = modal.find('.modal-body form');
                parent.children().remove();
                $(json.data).each(function(k, v){
                    if(!v.bills_date_end){ v.bills_date_end = ''; }
                    if(!v.bills_date_start){ v.bills_date_start = ''; }
                    if(!v.date_end){ v.date_end = ''; }
                    if(!v.date_send){ v.date_send = ''; }
                    if(!v.months){ v.months = 0; }
                    console.log(v);
                    parent.append($('<div class="row">\n' +
                        '                        <div class="col-sm-12 thread-title">\n' +
                        '                            <span class="">'+v.name+'</span>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Invio</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.date_send+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Fine Gestore o KO</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.date_end+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Periodo Censito Dal</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.bills_date_start+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Periodo Censito Al</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.bills_date_end+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Mesi di Fornitura</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+Math.round(Number(v.months))+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <div class="col-sm-6">\n' +
                        '                            <button class="btn btn-primary btn-animate widget-action" onclick="showBills('+v.id+')">\n' +
                        '                                <i class="fa fa-floppy-o"></i>\n' +
                        '                                <span class="btn-text">VEDI BOLLETTE</span>\n' +
                        '                                <div class="ripple-container"></div>\n' +
                        '                            </button>\n' +
                        '                        </div>\n' +
                        '                    </div>'));
                })
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function showBills(id){
    console.log('supplier history id: ', id);
    let modal = $('#history-billings-modal');
    $('.modal').modal('hide');
    modal.modal('show');
    var formData = new FormData();
    formData.append('action', 'get-supplier-history-billings');
    formData.append('id-supplier-history', id);
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                let parent = modal.find('.modal-body form');
                modal.find('.a-u-last-switch-id-data').val(id);
                parent.children().remove();
                $(json.data).each(function(k, v){
                    if(!v.date_start){ v.date_start = ''; }
                    if(!v.date_end){ v.date_end = ''; }
                    if(!v.date_received){ v.date_received = ''; }
                    parent.append($('<div class="row">\n' +
                        '                        <div class="col-sm-12 thread-title">\n' +
                        '                            <a style="margin-right: 15px" href="javascript:newBillingCustom(' + v.id +')"><i class="fa fa-pencil"></i></a><span class="">Bolletta del '+v.date_received+'</span>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Inizio decorrenza</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.date_start+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                        <label class="col-sm-2 label-on-left">Fine decorrenza</label>\n' +
                        '                        <div class="col-sm-4">\n' +
                        '                            <div class="form-group label-floating is-empty">\n' +
                        '                                <label class="control-label"></label>\n' +
                        '                                <div class="input-group col-sm-12">\n' +
                        '                                    <input type="text" name="" disabled class="form-control"\n' +
                        '                                           value="'+v.date_end+'">\n' +
                        '                                </div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                  </div>\n' +
                        '                  <div class="row">' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Importo</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.total_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">More</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.delay_price_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Canone RAI</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.rai_fee_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Altri Servizi</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.more_services_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                  </div>\n' +
                        '                  <div class="row">' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">IVA 22</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.iva22_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">IVA 10</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.iva10_amount+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                  </div>\n' +
                        '                  <div class="row">' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Potenza Usata</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.used_power+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Consumo Usato</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.consumption+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                      <div class="col-sm-3">\n' +
                        '                         <div class="form-group label-floating">\n' +
                        '                               <label class="control-label select2-label">Consumo Progressivo</label>\n' +
                        '                               <input type="text" name="switchContractCashedTypeLabel"\n' +
                        '                                      class="form-control"\n' +
                        '                                      value="'+v.progressive_consumption+'" disabled>\n' +
                        '                          </div>\n' +
                        '                       </div>' +
                        '                    </div>'));
                })
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function newBilling(element){
    $('.modal').modal('hide');
    let historyId = $(element).parent().parent().parent().parent().find('.a-u-last-switch-id-data').val();
    let pod = $(element).parent().parent().parent().parent().find('[name="contract[pod][0][id]"]');
    let pdr = $(element).parent().parent().parent().parent().find('[name="contract[pdr][0][id]"]');
    console.log("pod", pod.length);
    console.log("pdr", pdr.length);
    let modal = $('#new-supplier-billing-modal');
    modal.find('.a-u-last-switch-id-data').val(historyId);
    modal.find('.input-group.date input').val('');
    modal.find('.no-gas').show();
    modal.find('.no-electric').show();
    if (pod.length > 0){
        modal.find('.no-electric').hide();
    }
    if (pdr.length > 0){
        modal.find('.no-gas').hide();
    }
    modal.modal('show');
}

function sendNewBilling(){
    let modal = $('#new-supplier-billing-modal');
    modal.modal('hide');
    swal({
        title: "Attenzione",
        text: "Verrà segnato un inserita una nuova bolletta!",
        type: "warning",
        showConfirmButton: true,
        showCancelButton: true,
        cancelButtonColor: "#d9534f",
        cancelButtonText: "Annulla",
        confirmButtonColor: "#5cb85c",
        confirmButtonText: "Salva",
        closeOnConfirm: false
    }, function() {
        swal({
            html: true,
            title: "Salvataggio",
            text: 'Stiamo verificando l\'integrità dei dati.<br>Ci vorranno pochi secondi.<br><br>' +
                '<div class="progress">\n' +
                '\t<div style="width: 100%;" class="progress-bar progress-bar-primary progress-bar-striped active"></div>\n' +
                '</div>',
            showConfirmButton: false,
            showCancelButton: false,
            closeOnConfirm: false
        });
        OutLay.currentSA.kill = setTimeout(function () {
            swal.close();
            var error = "Risposta del server innafidabile. Ritentare o contattare il supporto tecnico.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        }, 2*60*1000);
        ajaxSaveNewBilling();
    });
}

function ajaxSaveNewBilling(){
    let modal = $('#new-supplier-billing-modal');
    let formData = new FormData();
    formData.append('action', 'new-supplier-history-billing');
    formData.append('billing-id', modal.find('[name=billing-id]').val());
    formData.append('id-supplier-history', modal.find('.a-u-last-switch-id-data').val());
    formData.append('date-start', modal.find('[name=modalDateStart]').val());
    formData.append('date-end', modal.find('[name=modalDateEnd]').val());
    formData.append('date-received', modal.find('[name=modalDateReceived]').val());
    formData.append('total-amount', modal.find('[name=total-amount]').val().replace(',', '.'));
    formData.append('delay-price-amount', modal.find('[name=delay-price-amount]').val().replace(',', '.'));
    formData.append('rai-fee-amount', modal.find('[name=rai-fee-amount]').val().replace(',', '.'));
    formData.append('more-services-amount', modal.find('[name=more-services-amount]').val().replace(',', '.'));
    formData.append('iva22-amount', modal.find('[name=iva22-amount]').val().replace(',', '.'));
    formData.append('iva10-amount', modal.find('[name=iva10-amount]').val().replace(',', '.'));
    formData.append('social-bonus', modal.find('[name=social-bonus]').val().replace(',', '.'));
    formData.append('used-power', modal.find('[name=used-power]').val().replace(',', '.'));
    formData.append('consumption', modal.find('[name=consumption]').val().replace(',', '.'));
    formData.append('progressive-consumption', modal.find('[name=progressive-consumption]').val().replace(',', '.'));
    formData.append('delays', modal.find('[name=delays]').prop('checked'));
    formData.append('postal-payment', modal.find('[name=postal-payment]').prop('checked'));
    modal.find('[name=billing-id]').val('');
    modal.find('.a-u-last-switch-id-data').val('')
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                if(json.status === 'OK' || json.status == 200){
                    modal.find('[name=modalDateReceived]').val()
                    /*$('.a-u-last-switch-id-data').each(function(k, v){
                        if(v.value == id){
                            $(v).parent().find('.supplier-date-send').val(json['new-date']);
                        }
                    })*/
                    //heading, text, icon, duration
                    location.reload();
                } else {
                    for(var i in json.errors){
                        var error = json.errors[i];
                        error = new OutLay.error("customer.data", {
                            error: error.error,
                            subject: error.message
                        });
                        error.display();
                    }
                }
                console.log(json);
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}

function newBillingCustom(id){
    console.log(id)
    $('.modal').modal('hide');
    let modal = $('#new-supplier-billing-modal');
    modal.find('.input-group.date input').val('');
    modal.find('.no-gas').show();
    modal.find('.no-electric').show();
    modal.find('.billing-id').val(id);
    ajaxGetBilling(id)
}

function ajaxGetBilling(id){
    let modal = $('#new-supplier-billing-modal');
    let formData = new FormData();
    formData.append('action', 'get-supplier-history-billing');
    formData.append('billing-id', id);
    /*
    formData.append('id-supplier-history', modal.find('.a-u-last-switch-id-data').val());
    formData.append('date-start', modal.find('[name=modalDateStart]').val());
    formData.append('date-end', modal.find('[name=modalDateEnd]').val());
    formData.append('date-received', modal.find('[name=modalDateReceived]').val());
    formData.append('total-amount', modal.find('[name=total-amount]').val().replace(',', '.'));
    formData.append('delay-price-amount', modal.find('[name=delay-price-amount]').val().replace(',', '.'));
    formData.append('rai-fee-amount', modal.find('[name=rai-fee-amount]').val().replace(',', '.'));
    formData.append('more-services-amount', modal.find('[name=more-services-amount]').val().replace(',', '.'));
    formData.append('iva22-amount', modal.find('[name=iva22-amount]').val().replace(',', '.'));
    formData.append('iva10-amount', modal.find('[name=iva10-amount]').val().replace(',', '.'));
    formData.append('social-bonus', modal.find('[name=social-bonus]').val().replace(',', '.'));
    formData.append('used-power', modal.find('[name=used-power]').val().replace(',', '.'));
    formData.append('consumption', modal.find('[name=consumption]').val().replace(',', '.'));
    formData.append('progressive-consumption', modal.find('[name=progressive-consumption]').val().replace(',', '.'));
    formData.append('delays', modal.find('[name=delays]').prop('checked'));
    formData.append('postal-payment', modal.find('[name=postal-payment]').prop('checked'));

     */
    $.ajax({
        url: "/ajax" + document.location.href.substr(document.location.origin.length),
        type: 'POST',
        data: formData,
        async: true,
        success: function (data) {
            clearTimeout(OutLay.currentSA.kill);
            swal.close();
            try{
                var json = JSON.parse(data);
                if(json.status === 'OK' || json.status == 200){
                    data = json.data
                    modal.find('[name=billing-id]').val(id)
                    modal.find('.a-u-last-switch-id-data').val(data.id_agreementSupplierHistory)
                    modal.find('[name=modalDateReceived]').val(data.date_received)
                    modal.find('[name=modalDateStart]').val(data.date_start)
                    modal.find('[name=modalDateEnd]').val(data.date_end)
                    modal.find('[name=modalDateReceived]').val(data.date_received)
                    modal.find('[name=total-amount]').val(data.total_amount)
                    modal.find('[name=delay-price-amount]').val(data.delay_price_amount)
                    modal.find('[name=rai-fee-amount]').val(data.rai_fee_amount)
                    modal.find('[name=more-services-amount]').val(data.more_services_amount)
                    modal.find('[name=iva22-amount]').val(data.iva22_amount)
                    modal.find('[name=iva10-amount]').val(data.iva10_amount)
                    modal.find('[name=social-bonus]').val(data.social_bonus)
                    modal.find('[name=used-power]').val(data.used_power)
                    modal.find('[name=consumption]').val(data.consumption)
                    modal.find('[name=progressive-consumption]').val(data.progressive_consumption)
                    if(data.delays) {
                        modal.find('[name=delays]').prop('checked', true)
                    }
                    if(data.postal_payment) {
                        modal.find('[name=postal-payment]').prop('checked', true)
                    }
                    modal.find('[name=delays]').val(data.delays)
                    // modal.find('[name=postal-payment]').val(data.postal_payment)
                    modal.modal('show');
                } else {
                    for(var i in json.errors){
                        var error = json.errors[i];
                        error = new OutLay.error("customer.data", {
                            error: error.error,
                            subject: error.message
                        });
                        error.display();
                    }
                }
                console.log(json);
            } catch(error){
                error = new OutLay.error("xhr.response", {
                    error: error,
                    subject: error
                });
                error.display();
            }
        },
        fail: function(data){
            swal.close();
            clearTimeout(OutLay.currentSA.kill);
            var error = "Abbiamo riscontrato un errore nella communicazione con il server.";
            error = new OutLay.error("xhr.response", {
                error: error,
                subject: error
            });
            error.display();
        },
        cache: false,
        contentType: false,
        processData: false
    });
}
